package internal

import (
	"fmt"
	"net/http"
	"net/url"
	"time"

	"gitea.dwysokinski.me/twhelp/dcbot/internal/twhelp"
	"github.com/kelseyhightower/envconfig"
)

type twhelpClientConfig struct {
	URL     *url.URL      `envconfig:"URL" required:"true"`
	Timeout time.Duration `envconfig:"TIMEOUT" default:"10s"`
}

func NewTWHelpClient(version string) (*twhelp.Client, error) {
	var cfg twhelpClientConfig
	if err := envconfig.Process("TWHELP", &cfg); err != nil {
		return nil, fmt.Errorf("envconfig.Process: %w", err)
	}

	return twhelp.NewClient(
		cfg.URL,
		twhelp.WithHTTPClient(&http.Client{
			Timeout: cfg.Timeout,
		}),
		twhelp.WithUserAgent("TWHelpDCBot/"+version),
	), nil
}
