package model

import (
	"time"

	"gitea.dwysokinski.me/twhelp/dcbot/internal/domain"
	"github.com/google/uuid"
	"github.com/uptrace/bun"
)

type Group struct {
	bun.BaseModel `bun:"base_model,table:groups,alias:group"`

	ID            uuid.UUID `bun:"id,type:uuid,pk,default:gen_random_uuid()"`
	ServerID      string    `bun:"server_id,type:varchar(100),notnull"`
	ChannelGains  string    `bun:"channel_gains,type:varchar(100),nullzero"`
	ChannelLosses string    `bun:"channel_losses,type:varchar(100),nullzero"`
	Internals     bool      `bun:"internals,default:false"`
	Barbarians    bool      `bun:"barbarians,default:false"`
	ServerKey     string    `bun:"server_key,type:varchar(50),notnull"`
	VersionCode   string    `bun:"version_code,type:varchar(6),notnull"`
	CreatedAt     time.Time `bun:"created_at,nullzero,notnull,default:current_timestamp"`
}

func (g Group) ToDomain() domain.Group {
	return domain.Group{
		ID:            g.ID.String(),
		ServerID:      g.ServerID,
		ChannelGains:  g.ChannelGains,
		ChannelLosses: g.ChannelLosses,
		Internals:     g.Internals,
		Barbarians:    g.Barbarians,
		ServerKey:     g.ServerKey,
		VersionCode:   g.VersionCode,
		CreatedAt:     g.CreatedAt,
	}
}
