package domain_test

import (
	"fmt"
	"testing"

	"gitea.dwysokinski.me/twhelp/dcbot/internal/domain"
	"github.com/stretchr/testify/assert"
)

func TestServerDoesNotExistError(t *testing.T) {
	t.Parallel()

	err := domain.ServerDoesNotExistError{
		VersionCode: "pl",
		Key:         "pl151",
	}
	var _ domain.Error = err
	assert.Equal(t, fmt.Sprintf("server (VersionCode=%s,Key=%s) doesn't exist", err.VersionCode, err.Key), err.Error())
	assert.Equal(t, err.Error(), err.UserError())
	assert.Equal(t, domain.ErrorCodeValidationError, err.Code())
}

func TestServerIsClosedError(t *testing.T) {
	t.Parallel()

	err := domain.ServerIsClosedError{
		VersionCode: "pl",
		Key:         "pl151",
	}
	var _ domain.Error = err
	assert.Equal(t, fmt.Sprintf("server (VersionCode=%s,Key=%s) is closed", err.VersionCode, err.Key), err.Error())
	assert.Equal(t, err.Error(), err.UserError())
	assert.Equal(t, domain.ErrorCodeValidationError, err.Code())
}

func TestTribeDoesNotExistError(t *testing.T) {
	t.Parallel()

	err := domain.TribeDoesNotExistError{
		Tag: "*TAG*",
	}
	var _ domain.Error = err
	assert.Equal(t, fmt.Sprintf("tribe (Tag=%s) doesn't exist", err.Tag), err.Error())
	assert.Equal(t, err.Error(), err.UserError())
	assert.Equal(t, domain.ErrorCodeValidationError, err.Code())
}
